"""Web interface exports for the refinance calculator."""

from __future__ import annotations

from .app import main

__all__ = ["main"]

__description__ = """
Streamlit web application exports for the refinance calculator.
"""
